'******************************************************************************
'*                                                                            *
'*                                LayGO (tm)                                  *
'*           Copyright (c) 1998-2000 by Advanced Relay Corporation            *
'*                          All rights reserved.                              *
'*                                                                            *
'******************************************************************************
'*
'*  $Source: q:/laygorcs/Laygo32.bas $
'*
'*      $Id: Laygo32.bas 1.14 2000/02/28 23:55:40 tiktin Release $
'*
'*  MODULE DESCRIPTION
'*
'*    Exports LayGO API functions and constants.
'*
'*    The functions exported by the usual LayGO 32-bit DLLs use the C
'*    calling convention for compatibility with all compilers.  Visual
'*    Basic expects functions exported by DLLs to use the standard call
'*    calling convention instead.  The DLL LAYGO32S.DLL exports all LayGO
'*    API functions using the standard call calling convention.  The DLL
'*    LAYGO32Y.DLL exports a subset of the LayGO X.25 Call functions using
'*    the standard call calling convention.
'*
'*    The lgo_GetXxxxxMessage() functions are similar to the corresponding
'*    lgo_XxxxxxMessage() functions except that they copy the requested
'*    message string into a user supplied buffer instead of returning a
'*    pointer to a string.  (Visual Basic cannot dereference a pointer to
'*    print a string.)  Each lgo_GetXxxxxMessage() function is wrapped by
'*    a Visual Basic function called lgo_XxxxxxMessage() which returns
'*    an object of type String.
'*
'*    The LayGO X.25 Call library relies extensively on pointers to C
'*    structs which cannot reliably be used by Visual Basic.  So only a
'*    subset of the Call library API is supported.  Call setup packets can
'*    still be encoded using the EDCALL.EXE utility and loaded at runtime
'*    using call_LoadCallData() which is supported.
'*
'******************************************************************************

Attribute VB_Name = "LaygoModule"

'******************************************************************************
'*
'*  Define LayGO Constants
'*
'******************************************************************************
Public Const ERROR_MIN As Integer = -52
Public Const ERROR_INVALID_USER_ID As Integer = -51
Public Const ERROR_INVALID_HARDWARE_VERSION As Integer = -50
Public Const ERROR_INVALID_DRIVER_VERSION As Integer = -49
Public Const ERROR_CLIENTS_CONNECTED As Integer = -48
Public Const ERROR_SERVER_NOT_CONNECTED As Integer = -47
Public Const ERROR_SERVER_CONNECTED As Integer = -46
Public Const ERROR_INVALID_CONFIGURATION As Integer = -45
Public Const ERROR_INVALID_PROTOCOL As Integer = -44
Public Const ERROR_CONFIGURATION_FILE_WRITE_ERROR As Integer = -43
Public Const ERROR_INVALID_DRIVER_CONFIGURATION As Integer = -42
Public Const ERROR_INVALID_STACK_CONFIGURATION As Integer = -41
Public Const ERROR_PROTOCOL_BLOCKING As Integer = -40
Public Const ERROR_INVALID_WRITE_DATA_SIZE As Integer = -39
Public Const ERROR_WRITE_QUEUE_FULL As Integer = -38
Public Const ERROR_SERVER_NOT_FOUND As Integer = -37
Public Const ERROR_SERVER_ACCESS_NOT_ENABLED As Integer = -36
Public Const ERROR_DRIVER_MODULE_FILE_NOT_FOUND As Integer = -35
Public Const ERROR_DRIVER_MODULE_FILE_READ_ERROR As Integer = -34
Public Const ERROR_INVALID_STACK_ID As Integer = -33
Public Const ERROR_INVALID_BOARD_ID As Integer = -32
Public Const ERROR_DRIVER_MODULE_INITIALIZATION_FAILURE As Integer = -31
Public Const ERROR_INVALID_DRIVER_MODULE As Integer = -30
Public Const ERROR_DRIVER_NOT_INSTALLED As Integer = -29
Public Const ERROR_HARDWARE_CONFIGURATION_CONFLICT As Integer = -28
Public Const ERROR_INVALID_HARDWARE_CONFIGURATION As Integer = -27
Public Const ERROR_SPECIAL_DATA_WAITING As Integer = -26
Public Const ERROR_INVALID_CID As Integer = -25
Public Const ERROR_INVALID_COMMAND As Integer = -24
Public Const ERROR_INVALID_INPUT_BUFFER As Integer = -23
Public Const ERROR_INVALID_OUTPUT_BUFFER As Integer = -22
Public Const ERROR_BUFFER_SIZE As Integer = -21
Public Const ERROR_NO_SYSTEM_BUFFER As Integer = -20
Public Const ERROR_TRANSMISSION_BLOCKED As Integer = -19
Public Const ERROR_SERVICE_DATABASE_NOT_FOUND As Integer = -18
Public Const ERROR_SERVICE_UNKNOWN As Integer = -17
Public Const ERROR_SERVICE_NOT_AVAILABLE As Integer = -16
Public Const ERROR_EVENT_WAITING As Integer = -15
Public Const ERROR_DATA_WAITING As Integer = -14
Public Const ERROR_NOTHING_WAITING As Integer = -13
Public Const ERROR_INVALID_IOCTL_FUNCTION As Integer = -12
Public Const ERROR_INVALID_IOCTL_PARAMETERS As Integer = -11
Public Const ERROR_HARDWARE_INITIALIZATION_FAILURE As Integer = -10
Public Const ERROR_BUFFER_POOL_INITIALIZATION_FAILURE As Integer = -9
Public Const ERROR_STACK_INITIALIZATION_FAILURE As Integer = -8
Public Const ERROR_OUT_OF_CONNECTIONS As Integer = -7
Public Const ERROR_OUT_OF_MEMORY As Integer = -6
Public Const ERROR_CONFIGURATION_FILE_NOT_FOUND As Integer = -5
Public Const ERROR_CONFIGURATION_FILE_READ_ERROR As Integer = -4
Public Const ERROR_UNKNOWN_PROTOCOL As Integer = -3
Public Const ERROR_CONFIGURATION_NOT_DEFINED As Integer = -2
Public Const ERROR_CONFIGURATION_NOT_FOUND As Integer = -1
Public Const ERROR_MAX As Integer = 0

Public Const EVENT_CONNECT As Integer = 0
Public Const EVENT_DISCONNECT As Integer = 1
Public Const EVENT_CONFIRM As Integer = 2
Public Const EVENT_LISTEN As Integer = 3
Public Const EVENT_ACCEPT As Integer = 4
Public Const EVENT_REFUSE As Integer = 5
Public Const EVENT_CANCEL As Integer = 6
Public Const EVENT_WRITE As Integer = 7
Public Const EVENT_XOFF As Integer = 8
Public Const EVENT_XON As Integer = 9
Public Const EVENT_RESET As Integer = 10
Public Const EVENT_REOPEN As Integer = 11
Public Const EVENT_IOCTL As Integer = 12
Public Const EVENT_USER_EVENT_MAX As Integer = 13

Public Const EVENT_CONNECT_REQUEST As Integer = 13
Public Const EVENT_CONNECTED As Integer = 14
Public Const EVENT_CONNECT_TIMEOUT As Integer = 15
Public Const EVENT_CONNECT_ACCEPT As Integer = 16
Public Const EVENT_CONNECT_REFUSE As Integer = 17
Public Const EVENT_DISCONNECT_REQUEST As Integer = 18
Public Const EVENT_DISCONNECTED As Integer = 19
Public Const EVENT_DISCONNECTING As Integer = 20
Public Const EVENT_DISCONNECT_TIMEOUT As Integer = 21
Public Const EVENT_DISCONNECT_CONFIRMATION As Integer = 22
Public Const EVENT_XOFF_REQUEST As Integer = 23
Public Const EVENT_XON_REQUEST As Integer = 24
Public Const EVENT_RESETTING As Integer = 25
Public Const EVENT_RESET_COMPLETED As Integer = 26
Public Const EVENT_RESET_TIMEOUT As Integer = 27
Public Const EVENT_DATA_OK As Integer = 28
Public Const EVENT_DATA_LENGTH_ERROR As Integer = 29
Public Const EVENT_DATA_CRC_ERROR As Integer = 30
Public Const EVENT_DATA_ABORTED_FRAME As Integer = 31
Public Const EVENT_PROTOCOL_MESSAGE As Integer = 32
Public Const EVENT_PACKET_EVENT_MAX As Integer = 33

Public Const PROTOCOL_SDLC_HARDWARE As Integer = 0
Public Const PROTOCOL_SYSTEM_BUFFER_POOL As Integer = 1
Public Const PROTOCOL_SYSTEM_STACK As Integer = 2
Public Const PROTOCOL_RESERVED_3 As Integer = 3
Public Const PROTOCOL_X21_BIS As Integer = 4
Public Const PROTOCOL_HDLC_LAPB As Integer = 5
Public Const PROTOCOL_X25_MAJOR_DEVICE As Integer = 6
Public Const PROTOCOL_X25_PVC As Integer = 7
Public Const PROTOCOL_X25_SVC As Integer = 8
Public Const PROTOCOL_RETURN As Integer = 9
Public Const PROTOCOL_RESERVED_10 As Integer = 10
Public Const PROTOCOL_FRAME_RELAY_MAJOR_DEVICE As Integer = 11
Public Const PROTOCOL_FRAME_RELAY_VC As Integer = 12
Public Const PROTOCOL_FRAME_RELAY_SVC As Integer = 13
Public Const PROTOCOL_LAPD_MAJOR_DEVICE As Integer = 14
Public Const PROTOCOL_LAPD_TEI As Integer = 15
Public Const PROTOCOL_RESERVED_16 As Integer = 16
Public Const PROTOCOL_RESERVED_17 As Integer = 17
Public Const PROTOCOL_MAX As Integer = 18

Public Const STATE_CLOSED As Integer = -1
Public Const STATE_OPEN As Integer = 0
Public Const STATE_WAITING_FOR_REMOTE_ACCEPT As Integer = 1
Public Const STATE_LISTENING As Integer = 2
Public Const STATE_WAITING_FOR_LOCAL_ACCEPT As Integer = 3
Public Const STATE_DATA_TRANSFER_XON As Integer = 4
Public Const STATE_DATA_TRANSFER_XOFF As Integer = 5
Public Const STATE_RESETTING As Integer = 6
Public Const STATE_WAITING_FOR_REMOTE_CONFIRMATION As Integer = 7
Public Const STATE_WAITING_FOR_LOCAL_CONFIRMATION As Integer = 8
Public Const STATE_MAX As Integer = 9

Public Const EVENT_MAX As Integer = EVENT_PACKET_EVENT_MAX
Public Const EVENT_NONE As Integer = ERROR_NOTHING_WAITING
Public Const EVENT_DATA_SPECIAL As Integer = EVENT_PACKET_EVENT_MAX

'******************************************************************************
'*
'*  LayGO API functions
'*
'******************************************************************************
Declare Function lgo_Attach Lib "laygo32s.dll" Alias "_lgt_Attach@4" (ByVal s As String) As Integer
Declare Function lgo_AttachProtocol Lib "laygo32s.dll" Alias "_lgt_AttachProtocol@12" (ByVal c1 As Integer, ByVal c2 As Integer, ByVal c3 As Integer) As Integer
Declare Function lgo_ClearStatistics Lib "laygo32s.dll" Alias "_lgt_ClearStatistics@4" (ByVal c As Integer) As Integer
Declare Function lgo_Close Lib "laygo32s.dll" Alias "_lgt_Close@4" (ByVal c As Integer) As Integer
Declare Function lgo_ConnectAccept Lib "laygo32s.dll" Alias "_lgt_ConnectAccept@12" (ByVal c As Integer, x As Any, ByVal i As Integer) As Integer
Declare Function lgo_ConnectReject Lib "laygo32s.dll" Alias "_lgt_ConnectReject@12" (ByVal c As Integer, x As Any, ByVal i As Integer) As Integer
Declare Function lgo_ConnectRequest Lib "laygo32s.dll" Alias "_lgt_ConnectRequest@12" (ByVal c As Integer, x As Any, ByVal i As Integer) As Integer
Declare Function lgo_Detach Lib "laygo32s.dll" Alias "_lgt_Detach@4" (ByVal c As Integer) As Integer
Declare Function lgo_DiscardData Lib "laygo32s.dll" Alias "_lgt_DiscardData@4" (ByVal c As Integer) As Integer
Declare Function lgo_DisconnectConfirm Lib "laygo32s.dll" Alias "_lgt_DisconnectConfirm@12" (ByVal c As Integer, x As Any, ByVal i As Integer) As Integer
Declare Function lgo_DisconnectRequest Lib "laygo32s.dll" Alias "_lgt_DisconnectRequest@12" (ByVal c As Integer, x As Any, ByVal i As Integer) As Integer
Declare Function lgo_Event Lib "laygo32s.dll" Alias "_lgt_Event@12" (ByVal c As Integer, x As Any, i As Integer) As Integer
Declare Function lgo_GetConfiguration Lib "laygo32s.dll" Alias "_lgt_GetConfiguration@12" (ByVal c As Integer, x As Any, ByVal i As Integer) As Integer
Declare Function lgo_GetStatistics Lib "laygo32s.dll" Alias "_lgt_GetStatistics@12" (ByVal c As Integer, x As Any, ByVal i As Integer) As Integer
Declare Function lgo_GetStatus Lib "laygo32s.dll" Alias "_lgt_GetStatus@12" (ByVal c As Integer, x As Any, ByVal i As Integer) As Integer
Declare Function lgo_Initialize Lib "laygo32s.dll" Alias "_lgt_Initialize@4" (ByVal c As Integer) As Integer
Declare Function lgo_Ioctl Lib "laygo32s.dll" Alias "_lgt_Ioctl@24" (ByVal c As Integer, ByVal i As Integer, x As Any, ByVal j As Integer, x As Any, k As Integer) As Integer
Declare Function lgo_Listen Lib "laygo32s.dll" Alias "_lgt_Listen@4" (ByVal c As Integer) As Integer
Declare Function lgo_ListenCancel Lib "laygo32s.dll" Alias "_lgt_ListenCancel@4" (ByVal c As Integer) As Integer
Declare Function lgo_LoadConfiguration Lib "laygo32s.dll" Alias "_lgt_LoadConfiguration@16" (ByVal s As String, ByVal c As Integer, x As Any, ByVal i As Integer) As Integer
Declare Function lgo_MaxBufferSize Lib "laygo32s.dll" Alias "_lgt_MaxBufferSize@4" (ByVal c As Integer) As Integer
Declare Function lgo_Open Lib "laygo32s.dll" Alias "_lgt_Open@4" (ByVal s As String) As Integer
Declare Function lgo_OpenProtocol Lib "laygo32s.dll" Alias "_lgt_OpenProtocol@12" (ByVal c1 As Integer, ByVal c2 As Integer, ByVal c3 As Integer) As Integer
Declare Function lgo_Poll Lib "laygo32s.dll" Alias "_lgt_Poll@8" (ByVal c As Integer, i As Integer) As Integer
Declare Function lgo_Pop Lib "laygo32s.dll" Alias "_lgt_Pop@4" (ByVal c As Integer) As Integer
Declare Function lgo_Protocol Lib "laygo32s.dll" Alias "_lgt_Protocol@4" (ByVal c As Integer) As Integer
Declare Function lgo_Push Lib "laygo32s.dll" Alias "_lgt_Push@8" (ByVal c1 As Integer, ByVal c2 As Integer) As Integer
Declare Function lgo_Read Lib "laygo32s.dll" Alias "_lgt_Read@12" (ByVal c As Integer, x As Any, ByVal i As Integer) As Integer
Declare Function lgo_ReadNext Lib "laygo32s.dll" Alias "_lgt_ReadNext@12" (c As Integer, x As Any, ByVal i As Integer) As Integer
Declare Function lgo_ReadSpecial Lib "laygo32s.dll" Alias "_lgt_ReadSpecial@16" (ByVal c As Integer, x As Any, ByVal i As Integer, j As Integer) As Integer
Declare Function lgo_Reopen Lib "laygo32s.dll" Alias "_lgt_Reopen@4" (ByVal c As Integer) As Integer
Declare Function lgo_ResetRequest Lib "laygo32s.dll" Alias "_lgt_ResetRequest@12" (ByVal c As Integer, x As Any, ByVal i As Integer) As Integer
Declare Function lgo_SaveConfiguration Lib "laygo32s.dll" Alias "_lgt_SaveConfiguration@16" (ByVal s As String, ByVal c As Integer, x As Any, ByVal i As Integer) As Integer
Declare Function lgo_SetConfiguration Lib "laygo32s.dll" Alias "_lgt_SetConfiguration@12" (ByVal c As Integer, x As Any, ByVal i As Integer) As Integer
Declare Function lgo_State Lib "laygo32s.dll" Alias "_lgt_State@4" (ByVal c As Integer) As Integer
Declare Function lgo_Uninitialize Lib "laygo32s.dll" Alias "_lgt_Uninitialize@0" () As Integer
Declare Function lgo_Write Lib "laygo32s.dll" Alias "_lgt_Write@12" (ByVal c As Integer, x As Any, ByVal i As Integer) As Integer
Declare Function lgo_WriteSpecial Lib "laygo32s.dll" Alias "_lgt_WriteSpecial@16" (ByVal c As Integer, x As Any, ByVal i As Integer, ByVal j As Integer) As Integer
Declare Function lgo_Xoff Lib "laygo32s.dll" Alias "_lgt_Xoff@4" (ByVal c As Integer) As Integer
Declare Function lgo_Xon Lib "laygo32s.dll" Alias "_lgt_Xon@4" (ByVal c As Integer) As Integer

'******************************************************************************
'*
'*  Supervisory functions
'*
'******************************************************************************
Declare Function lgo_ActivateStack Lib "laygo32s.dll" Alias "_lgt_ActivateStack@0" () As Integer
Declare Function lgo_ConfigureStack Lib "laygo32s.dll" Alias "_lgt_ConfigureStack@4" (ByVal s As String) As Integer
Declare Function lgo_DisableStack Lib "laygo32s.dll" Alias "_lgt_DisableStack@0" () As Integer
Declare Function lgo_EnableStack Lib "laygo32s.dll" Alias "_lgt_EnableStack@0" () As Integer
Declare Function lgo_GetBufferPoolStatistics Lib "laygo32s.dll" Alias "_lgt_GetBufferPoolStatistics@8" (x As Any, ByVal i As Integer) As Integer
Declare Function lgo_GetDriverId Lib "laygo32s.dll" Alias "_lgt_GetDriverId@0" () As Integer
Declare Function lgo_InitializeServiceDatabase Lib "laygo32s.dll" Alias "_lgt_InitializeServiceDatabase@4" (ByVal s As String) As Integer
Declare Function lgo_InitializeStack Lib "laygo32s.dll" Alias "_lgt_InitializeStack@8" (ByVal c1 As Integer, ByVal c2 As Integer) As Integer
Declare Function lgo_SetDefaultConfiguration Lib "laygo32s.dll" Alias "_lgt_SetDefaultConfiguration@12" (ByVal c As Integer, x As Any, ByVal i As Integer) As Integer
Declare Function lgo_UninitializeServiceDatabase Lib "laygo32s.dll" Alias "_lgt_UninitializeServiceDatabase@0" () As Integer
Declare Function lgo_UninitializeStack Lib "laygo32s.dll" Alias "_lgt_UninitializeStack@0" () As Integer
Declare Function lgo_ValidateUserId Lib "laygo32s.dll" Alias "_lgt_ValidateUserId@4" (ByVal c As Long) As Integer

'******************************************************************************
'*
'*  Intelligent board downloading functions
'*
'******************************************************************************
Declare Function lgo_DownloadDriverModule Lib "laygo32s.dll" Alias "_lgt_DownloadDriverModule@8" (ByVal s As String) As Integer
Declare Function lgo_CheckDriverModuleInitialization Lib "laygo32s.dll" Alias "_lgt_CheckDriverModuleInitialization@4" (ByVal c As Integer) As Integer
Declare Function lgo_InitializeHardware Lib "laygo32s.dll" Alias "_lgt_InitializeHardware@4" (ByVal c As Integer) As Integer
Declare Function lgo_CheckHardwareInitialization Lib "laygo32s.dll" Alias "_lgt_CheckHardwareInitialization@4" (ByVal c As Integer) As Integer

'******************************************************************************
'*
'*  RPC server control functions
'*
'******************************************************************************
'Declare Function lgo_ConnectServer Lib "laygo32s.dll" Alias "_lgt_ConnectSever@4" (ByVal c As Integer) As Integer
'Declare Function lgo_ConnectServerIp Lib "laygo32s.dll" Alias "_lgt_ConnectSeverIp@4" (ByVal s As String) As Integer
'Declare Function lgo_ConnectServerLocal Lib "laygo32s.dll" Alias "_lgt_ConnectSeverLocal@0" () As Integer
'Declare Function lgo_DisconnectServer Lib "laygo32s.dll" Alias "_lgt_DisconnectSever@0" () As Integer
'Declare Function lgo_HeartbeatServer Lib "laygo32s.dll" Alias "_lgt_HeartbeatSever@0" () As Integer
'Declare Function lgo_ShutdownServer Lib "laygo32s.dll" Alias "_lgt_ShutdownServer@0" () As Integer

'*****************************************************************************
'*
'*  LayGO message functions
'*
'*****************************************************************************
Declare Function lgo_GetErrorMessage Lib "laygo32s.dll" Alias "_lgt_GetErrorMessage@12" (ByVal c As Integer, ByVal s As String, ByVal i As Integer) As Integer
Declare Function lgo_GetEventMessage Lib "laygo32s.dll" Alias "_lgt_GetEventMessage@12" (ByVal c As Integer, ByVal s As String, ByVal i As Integer) As Integer
Declare Function lgo_GetProtocolMessage Lib "laygo32s.dll" Alias "_lgt_GetProtocolMessage@12" (ByVal c As Integer, ByVal s As String, ByVal i As Integer) As Integer
Declare Function lgo_GetStateMessage Lib "laygo32s.dll" Alias "_lgt_GetStateMessage@12" (ByVal c As Integer, ByVal s As String, ByVal i As Integer) As Integer
Declare Function lgo_GetStatisticMessage Lib "laygo32s.dll" Alias "_lgt_GetStatisticMessage@16" (ByVal c As Integer, ByVal i As Integer, ByVal s As String, ByVal n As Integer) As Integer

'******************************************************************************
'*
'*  X.25 message functions
'*
'******************************************************************************
'Declare Function dg_GetDiagnosticMessage Lib "Laygo32y.dll" Alias "_lgt_GetDiagnosticMessage@12" (ByVal c As Integer, ByVal S As String, ByVal i As Integer) As Integer
'Declare Function dg_GetClearingCauseMessage Lib "Laygo32y.dll" Alias "_lgt_GetClearingCauseMessage@12" (ByVal c As Integer, ByVal S As String, ByVal i As Integer) As Integer
'Declare Function dg_GetResettingCauseMessage Lib "Laygo32y.dll" Alias "_lgt_GetResettingCauseMessage@12" (ByVal c As Integer, ByVal S As String, ByVal i As Integer) As Integer
'Declare Function dg_GetRestartingCauseMessage Lib "Laygo32y.dll" Alias "_lgt_GetRestartingCauseMessage@12" (ByVal c As Integer, ByVal S As String, ByVal i As Integer) As Integer
'Declare Function dg_GetRegistrationCauseMessage Lib "Laygo32y.dll" Alias "_lgt_GetRegistrationCauseMessage@12" (ByVal c As Integer, ByVal S As String, ByVal i As Integer) As Integer

'******************************************************************************
'*
'*  X.25 call setup packet functions
'*
'*******************************************************************************
'Declare Function call_LoadCallData Lib "Laygo32y.dll" Alias "_lgt_LoadCallData@12" (ByVal F As String, x As Any, ByVal i As Integer) As Integer
'Declare Function call_GetPacketSize Lib "Laygo32y.dll" Alias "_lgt_GetPacketSize@12" (x As Any, ByVal i As Integer, ByVal b As Integer) As Integer

'******************************************************************************
'*
'*  LayGO message wrapper functions
'*
'******************************************************************************
Private Const lgo_MessageSize As Integer = 128
Private lgo_Message As String * lgo_MessageSize

Public Function lgo_ErrorMessage(ByVal i As Integer) As String
    Dim n As Integer

    n = lgo_GetErrorMessage(i, lgo_Message, lgo_MessageSize)

    lgo_ErrorMessage = Left(lgo_Message, n - 1)
End Function

Public Function lgo_EventMessage(ByVal i As Integer) As String
    Dim n As Integer

    n = lgo_GetEventMessage(ByVal i, lgo_Message, lgo_MessageSize)

    lgo_EventMessage = Left(lgo_Message, n - 1)
End Function

Public Function lgo_StateMessage(ByVal i As Integer) As String
    Dim n As Integer

    n = lgo_GetStateMessage(i, lgo_Message, lgo_MessageSize)

    lgo_StateMessage = Left(lgo_Message, n - 1)
End Function

Public Function lgo_ProtocolMessage(ByVal i As Integer) As String
    Dim n As Integer

    n = lgo_GetProtocolMessage(i, lgo_Message, lgo_MessageSize)

    lgo_ProtocolMessage = Left(lgo_Message, n - 1)
End Function

Public Function lgo_StatisticsMessage(ByVal protocol As Integer, ByVal i As Integer) As String
    Dim n As Integer

    n = lgo_GetStatisticMessage(protocol, i, lgo_Message, lgo_MessageSize)

    If n > 0 Then
        lgo_StatisticsMessage = Left(lgo_Message, n - 1)
    Else
        lgo_StatisticsMessage = "Undefined"
    End If
End Function

'******************************************************************************
'*
'*  X.25 message wrapper functions
'*
'******************************************************************************
'Private Const dg_MessageSize As Integer = 128
'Private dg_Message As String * dg_MessageSize
'
'Public Function dg_DiagnosticMessage(ByVal i As Integer) As String
'    Dim n As Integer
'
'    n = dg_GetDiagnosticMessage(i, dg_Message, dg_MessageSize)
'
'    dg_DiagnosticMessage = Left(dg_Message, n - 1)
'End Function
'
'Public Function dg_ClearingCauseMessage(ByVal i As Integer) As String
'    Dim n As Integer
'
'    n = dg_GetClearingCauseMessage(i, dg_Message, dg_MessageSize)
'
'    dg_ClearingCauseMessage = Left(dg_Message, n - 1)
'End Function
'
'Public Function dg_ResettingCauseMessage(ByVal i As Integer) As String
'    Dim n As Integer
'
'    n = dg_GetResettingCauseMessage(i, dg_Message, dg_MessageSize)
'
'    dg_ResettingCauseMessage = Left(dg_Message, n - 1)
'End Function
'
'Public Function dg_RestartingCauseMessage(ByVal i As Integer) As String
'    Dim n As Integer
'
'    n = dg_GetRestartingCauseMessage(i, dg_Message, dg_MessageSize)
'
'    dg_RestartingCauseMessage = Left(dg_Message, n - 1)
'End Function
'
'Public Function dg_RegistrationCauseMessage(ByVal i As Integer) As String
'    Dim n As Integer
'
'    n = dg_GetRegistrationCauseMessage(i, dg_Message, dg_MessageSize)
'
'    dg_RegistrationCauseMessage = Left(dg_Message, n - 1)
'End Function
'
'******************************************************************************
'*                                  End of file
'******************************************************************************

