'******************************************************************************
'*                                                                            *
'*                                LayGO (tm)                                  *
'*           Copyright (c) 1998-2000 by Advanced Relay Corporation            *
'*                           All rights reserved.                             *
'*                                                                            *
'******************************************************************************
'*
'*  $Source: q:/laygorcs/Tdat.bas $
'*
'*      $Id: Tdat.bas 1.2 2000/02/29 00:00:09 tiktin Release $
'*
'*  MODULE DESCRIPTION
'*
'*    Exports test data frame handling routines.
'*
'******************************************************************************

Attribute VB_Name = "TdatModule"

Option Explicit

Private Type TdatRecord
    name As String
    flag As Integer
    frame() As Byte
End Type

Private Const TdatIncrement As Integer = 32

Private Tdat() As TdatRecord
Private TdatCount As Integer
Private TdatFile As String

Public Function TdatGetCount() As Integer
    TdatGetCount = TdatCount
End Function

Public Function TdatGetFlag(i As Integer) As Integer
    If i < TdatCount Then
        TdatGetFlag = Tdat(i).flag
    Else
        TdatGetFlag = 0
    End If
End Function

Public Function TdatGetFrame(i As Integer) As Byte()
    If i < TdatCount Then
        TdatGetFrame = Tdat(i).frame
    Else
        TdatGetFrame = Array()
    End If
End Function

Public Function TdatGetLabel(i As Integer) As String
    If i < TdatCount Then
        TdatGetLabel = Tdat(i).name
    Else
        TdatGetLabel = "Invalid"
    End If
End Function

Public Function TdatGetSize(i As Integer) As Integer
    If i < TdatCount Then
        TdatGetSize = UBound(Tdat(i).frame)+1
    Else
        TdatGetSize = 0
    End If
End Function

Public Function TdatLoadFile(fileName As String) As Integer
    Dim str As String
    Dim tmp As String
    Dim file As Integer
    Dim i As Integer
    Dim j As Integer
    Dim flag As Integer
    Dim tlabel As String
    Dim count As Integer
    Dim quote As String
    Dim n As Integer

    quote = Chr(34)

    On Error GoTo OpenErrorHandler

    file = FreeFile()

    Open fileName For Input As file

    On Error GoTo InputErrorHandler

    count = 0

    ReDim Tdat(TdatIncrement) As TdatRecord
	TdatCount = 0
	TdatFile = ""

    Do While Not EOF(file)
        Line Input #file, str
        If Not IsComment(str) Then
            If IsEndOfFile(str) Then
                Exit Do
            ElseIf IsHeader(str) Then
                If count > 0 Then
                    ' Save completed frame
                    Tdat(count - 1).name = tlabel
                    Tdat(count - 1).flag = flag
                    ReDim Preserve Tdat(count - 1).frame(n - 1) As Byte
                End If

                ' Start new frame
                count = count + 1
                n = 0
                If count - 1 > UBound(Tdat) Then
                        ReDim Preserve Tdat(UBound(Tdat) + TdatIncrement) As TdatRecord
                End If
                ReDim Tdat(count - 1).frame(TdatIncrement) As Byte

                flag = GetFlag(str)
                tlabel = str
            Else
                If count > 0 Then
                    Do While Len(str) > 0
                        ' Find the next token
                        i = InStr(1, str, " ")
                        If i > 0 Then
                            tmp = Left(str, i - 1)
                            str = Trim(Right(str, Len(str) - i))
                        Else
                            tmp = str
                            str = ""
                        End If
                        ' Strip optional comma
                        If Right(tmp, 1) = "," Then
                            tmp = Left(tmp, Len(tmp) - 1)
                        End If
                        ' Quoted string of ASCII characters?
                        If Left(tmp, 1) = quote Then
                            tmp = Right(tmp, Len(tmp) - 1)
                            ' Strip close quote
                            If Right(tmp, 1) = quote Then
                                tmp = Left(tmp, Len(tmp) - 1)
                            End If
                            ' Convert each character to byte
                            For i = 1 To Len(tmp)
                                If n > UBound(Tdat(count - 1).frame) Then
                                    ReDim Preserve Tdat(count - 1).frame(UBound(Tdat(count - 1).frame) + TdatIncrement) As Byte
                                End If
                                Tdat(count - 1).frame(n) = CByte(Asc(Mid(tmp, i, 1)))
                                n = n + 1
                            Next
                        Else
                            ' Hex or binary digit
                            If n > UBound(Tdat(count - 1).frame) Then
                                ReDim Preserve Tdat(count - 1).frame(UBound(Tdat(count - 1).frame) + TdatIncrement) As Byte
                            End If
                            Tdat(count - 1).frame(n) = CByte(GetDigit(tmp))
                            n = n + 1
                        End If
                    Loop
                End If
            End If
        End If
    Loop

    If count > 0 Then
        ' Save completed frame
        Tdat(count - 1).name = tlabel
        Tdat(count - 1).flag = flag
        ReDim Preserve Tdat(count - 1).frame(n - 1) As Byte
        ' Save completed frame set
        ReDim Preserve Tdat(count - 1) As TdatRecord
        TdatCount = count
        TdatFile = fileName
    End If

    Close #file

    TdatLoadFile = TdatCount
    Exit Function

OpenErrorHandler:
    TdatLoadFile = 0
    Exit Function
InputErrorHandler:
    Close #file
    TdatLoadFile = 0
    Exit Function
End Function

Private Function IsComment(str As String) As Boolean
    Dim i As Integer

    IsComment = False

    i = InStr(str, "#")

    If i = 1 Then
        IsComment = True
    ElseIf i > 0 Then
        str = Trim(Left(str, i - 1))
        IsComment = Len(str) < 1
    End If
End Function

Private Function IsEndOfFile(str As String) As Boolean
    Dim i As Integer

    IsEndOfFile = False

    i = InStr(str, "]")

    If i = 1 Then
        IsEndOfFile = True
    End If
End Function

Private Function IsHeader(str As String) As Boolean
    Dim i As Integer

    IsHeader = False

    i = InStr(str, "[")

    If i = 1 Then
        IsHeader = True
        i = InStr(str, "]")
        If i > 0 Then
            str = Trim(Mid(str, 2, i - 2))
        End If
        If Len(str) < 1 Then
            str = "Unknown"
        End If
    End If
End Function

Private Function GetFlag(str As String) As Integer
    Dim i As Integer
    Dim flag As String

    GetFlag = 0

    i = InStr(str, "{")

    If i > 0 Then
        flag = Trim(Right(str, Len(str) - i))
        str = Trim(Left(str, i - 1))
        If Len(str) < 1 Then
            str = "Unknown"
        End If
        If Len(flag) > 0 Then
            i = InStr(flag, "}")
            If i > 0 Then
                flag = Trim(Left(flag, i - 1))
            End If
            GetFlag = GetDigit(flag)
        End If
    End If
End Function

Private Function GetDigit(str As String) As Integer
    Dim i As Integer
    Dim s As String
    Dim bin As Boolean

    On Error GoTo DigitError
    GetDigit = 0
    bin = False

    Trim (str)

    If Len(str) > 0 Then
        If Len(str) > 1 And Left(str, 1) = "0" Then
            ' Lead zero or radix prefix?
            s = Mid(str, 2, 1)
            If s = "%" Then
                bin = True
                str = Trim(Right(str, Len(str) - 2))
            ElseIf s = "x" Or s = "X" Then
                str = Trim(Right(str, Len(str) - 2))
            End If
        End If
        If bin Then
            GetDigit = GetBinDigit(str)
        Else
            GetDigit = GetHexDigit(str)
        End If
    End If

    Exit Function

DigitError:
    GetDigit = 0
    Exit Function
End Function

Private Function GetBinDigit(str As String) As Integer
    Dim i As Integer
    Dim n As Integer

    On Error GoTo BinDigitError

    n = 0
    For i = 1 To Len(str)
        n = n * 2
        If Mid(str, i, 1) = "1" Then
            n = n + 1
        End If
    Next

    GetBinDigit = n
    Exit Function

BinDigitError:
    GetBinDigit = 0
    Exit Function
End Function

Private Function GetHexDigit(str As String) As Integer
    Dim i As Integer
    Dim n As Integer
    Dim m

    On Error GoTo HexDigitError

    n = 0
    For i = 1 To Len(str)
        n = n * 16
        m = UCase(Mid(str, i, 1))
        Select Case m
        Case "0" To "9"
            n = n + m
        Case "A" To "F"
            n = n + Asc(m) - Asc("A") + 10
        Case Else
            Err.Raise 1
        End Select
    Next

    GetHexDigit = n
    Exit Function

HexDigitError:
    GetHexDigit = 0
    Exit Function
End Function

'******************************************************************************
'*                                  End of file                               *
'******************************************************************************
