'******************************************************************************
'*                                                                            *
'*                                LayGO (tm)                                  *
'*           Copyright (c) 1998-2000 by Advanced Relay Corporation            *
'*                           All rights reserved.                             *
'*                                                                            *
'******************************************************************************
'*
'*  $Source: q:/laygorcs/Vtx.bas $
'*
'*      $Id: Vtx.bas 1.2 2000/02/29 00:00:11 tiktin Release $
'*
'*  MODULE DESCRIPTION
'*
'*    Exports verified transmission frame handling routines.
'*
'******************************************************************************

Attribute VB_Name = "VtxModule"

Option Explicit

Public Const ERROR_INVALID_BUFFER_SIZE As Integer = -1
Public Const ERROR_INVALID_VTX_REFERENCE As Integer = -2
Public Const ERROR_SEQUENCE_NUMBER_DISCREPANCY As Integer = -3
Public Const ERROR_SIZE_DISCREPANCY As Integer = -4
Public Const ERROR_PATTERN_TYPE_DISCREPANCY As Integer = -5
Public Const ERROR_DATA_DISCREPANCY As Integer = -6
Public Const ERROR_NONE As Integer = 0

Private Const MODULUS As Long = 7
Private Const SIZEOF_HEADER As Long = 2
Private Const BUFFER_MIN As Long = 2
Private Const BUFFER_MAX As Long = 4096
Private Const PAD As Long = 4
Private Const DIRECTION_BIT As Long = 1
Private Const SEQUENCE_BITS As Long = &HE&
Private Const SIZE_LOW_BITS As Long = &HF0&
Private Const SIZE_HIGH_BITS As Long = &HFF&
Private Const SIZE_LOW_NIBBLE As Long = &HF&

Private VtxMax As Long
Private VtxForward() As Byte
Private VtxReverse() As Byte
Private VtxTxSequence As Long
Private VtxTxForward As Boolean
Private VtxRxSequence As Long

Public Sub VtxInitialize(max As Long)

    If max < BUFFER_MIN Then
        VtxMax = BUFFER_MIN
    ElseIf max > BUFFER_MAX Then
        VtxMax = BUFFER_MAX
    Else
        VtxMax = max
    End If

    ReDim VtxForward(VtxMax + PAD) As Byte
    ReDim VtxReverse(VtxMax + PAD) As Byte

    HexFill VtxForward, SIZEOF_HEADER, CInt(VtxMax), True
    HexFill VtxReverse, SIZEOF_HEADER, CInt(VtxMax), False

    VtxTxSequence = 0
    VtxTxForward = True
    VtxRxSequence = 0
End Sub

Public Function VtxGetTx(size As Long) As Byte()
    Dim buffer() As Byte
    Dim bit As Long

    If VtxTxForward Then
        buffer = VtxForward
        bit = 0
    Else
        buffer = VtxReverse
        bit = 1
    End If

    buffer(0) = CByte((((size - 1) And SIZE_LOW_NIBBLE) * 16) Or _
                    (((VtxTxSequence Mod MODULUS) * 2) And SEQUENCE_BITS) Or bit)
    buffer(1) = CByte(((size - 1) \ 16) And SIZE_HIGH_BITS)

    VtxGetTx = buffer
End Function

Public Sub VtxNextTx()
    VtxTxSequence = VtxTxSequence + 1
    VtxTxForward = Not VtxTxForward
End Sub

Public Sub VtxReset()
    VtxResetRx
    VtxResetTx
End Sub

Public Sub VtxResetRx()
    VtxRxSequence = 0
End Sub

Public Sub VtxResetTx()
    VtxTxSequence = 0
    VtxTxForward = True
End Sub

Public Function VtxValidateRx(buffer() As Byte, size As Long) As Integer
    Dim rxSequence As Long
    Dim rxSize As Long
    Dim pattern() As Byte
    Dim i As Long

    VtxValidateRx = ERROR_NONE

    If size < BUFFER_MIN Or size > VtxMax Then
        VtxValidateRx = ERROR_INVALID_BUFFER_SIZE
    Else
        rxSequence = (CLng(buffer(0)) And SEQUENCE_BITS) \ 2

        If rxSequence <> VtxRxSequence Then
            VtxRxSequence = (rxSequence + 1) Mod MODULUS
            VtxValidateRx = ERROR_SEQUENCE_NUMBER_DISCREPANCY
        Else
            VtxRxSequence = (VtxRxSequence + 1) Mod MODULUS
        End If

        rxSize = (CLng(buffer(1)) * 16) + ((CLng(buffer(0)) And SIZE_LOW_BITS) \ 16) + 1

        If rxSize <> size Then
            VtxValidateRx = ERROR_SIZE_DISCREPANCY
        End If

        If CLng(buffer(0)) And &H1& Then
            pattern = VtxReverse
        Else
            pattern = VtxForward
        End If

        For i = SIZEOF_HEADER To size - 1
            If buffer(i) <> pattern(i) Then
                VtxValidateRx = ERROR_DATA_DISCREPANCY
                Exit Function
            End If
        Next
    End If
End Function

Public Function VtxErrorMessage(i As Integer) As String
    Select Case i
    Case ERROR_INVALID_BUFFER_SIZE
            VtxErrorMessage = "Invalid buffer size"
    Case ERROR_SEQUENCE_NUMBER_DISCREPANCY
            VtxErrorMessage = "Sequence number discrepancy"
    Case ERROR_SIZE_DISCREPANCY
            VtxErrorMessage = "Size discrepancy"
    Case ERROR_DATA_DISCREPANCY
            VtxErrorMessage = "Data discrepancy"
    Case Else
            VtxErrorMessage = "Unknown error"
    End Select
End Function

'******************************************************************************
'*                                  End of file                               *
'******************************************************************************
